import javax.swing.*;
import junit.extensions.jfcunit.*;
import junit.extensions.jfcunit.finder.*;
import junit.extensions.jfcunit.eventdata.*;

public class CatalogEditorJFCTest extends JFCTestCase {

	private ProductCatalog catalog;
	
	//! the one and only editor
	private CatalogEditor editor;
	private ProductCreator addDialog;
		
	private JButton deleteButton;


	//! constructor of this test-class
	public CatalogEditorJFCTest(String name) {
		super(name);
	}

	protected void setUp() {
	
		setHelper (new JFCTestHelper());
	
		Product product1 = new Product("0001");
		product1.setDescription("Monitor");
		catalog = new SimpleProductCatalog();
		catalog.addProduct(product1);

		Product product2 = new Product("0002");
		product2.setDescription("Tastatur");
		catalog.addProduct(product2);

		Product product3 = new Product("0003");
		product3.setDescription("Mouse");
		catalog.addProduct(product3);

		//main editor
		editor = new CatalogEditor(catalog);
		editor.show();
	}
	
	public void testDeleteAll() {

		FrameFinder frame_finder = new FrameFinder("Product Editor");
		JFrame editor = (JFrame) frame_finder.find();
		
		
		ComponentFinder finder = new ComponentFinder(JButton.class);
		JButton deleteButton = ( JButton ) finder.find(editor, 1);
        	assertNotNull( "Could not find the Delete button", deleteButton );

		finder.setComponentClass(JList.class);
		JList productList = ( JList ) finder.find(editor, 0);
        	assertNotNull( "Could not find the List", productList );
		
		for(int i = 1; i <= 3; i++) {
			JListMouseEventData listClick = new JListMouseEventData (this, productList, 0, 1);
			getHelper().enterClickAndLeave(listClick);
			sleep(2000);
			MouseEventData deleteClick = new MouseEventData(this, deleteButton);
			getHelper().enterClickAndLeave(deleteClick);
		}
		assertEquals(0, productList.getModel().getSize());



	}

public void testAddProduct() {

		FrameFinder frame_finder = new FrameFinder("Product Editor");
		JFrame editor = (JFrame) frame_finder.find();
			
		ComponentFinder finder = new ComponentFinder(JButton.class);
		JButton addButton = ( JButton ) finder.find(editor, 0);
        	assertNotNull( "Could not find the Add button", addButton );

		MouseEventData addClick = new MouseEventData(this, addButton);
		getHelper().enterClickAndLeave(addClick);

		FrameFinder frame_finder2 = new FrameFinder("ProductCreator");
		JFrame creator = (JFrame) frame_finder2.find();
		assertEquals("ProductCreator", creator.getTitle());
		sleep(2000);
		
		finder.setComponentClass(JTextArea.class);
		JTextArea name = ( JTextArea ) finder.find(creator, 0);
        	assertNotNull( "Could not find the name TextArea", name );
		name.setText("0815");
		sleep(2000);
		
		JTextArea description = ( JTextArea ) finder.find(creator, 1);
        	assertNotNull( "Could not find the description TextArea", description );
		description.setText("Netzwerkkabel");
		sleep(2000);
		
		finder.setComponentClass(JButton.class);
 		JButton addProductButton = ( JButton ) finder.find(creator, 0);
    	  	assertNotNull( "Could not find the Add button", addProductButton );
		assertEquals("Add Product", addProductButton.getText());

		MouseEventData addProductClick = new MouseEventData(this, addProductButton);
		getHelper().enterClickAndLeave(addProductClick);
		sleep(2000);

		finder.setComponentClass(JList.class);
		JList productList = ( JList ) finder.find(editor, 0);
		assertEquals(4, productList.getModel().getSize());
		
		int i = productList.getNextMatch("0815", 0, javax.swing.text.Position.Bias.Forward);
		JListMouseEventData listClick = new JListMouseEventData (this, productList, i, 1);
		getHelper().enterClickAndLeave(listClick);
		sleep(2000);
		
		finder.setComponentClass(JTextArea.class);
		JTextArea descriptionArea = ( JTextArea ) finder.find(editor, 0);
		assertEquals("Netzwerk", descriptionArea.getText());

		
}

protected void tearDown() {
		getHelper().cleanUp(this);
	}


}
